@@ -173,9 +173,8 @@ rhandsontable <- function(data, colHeaders, rowHeaders, comments = NULL,
 #' @param hot rhandsontable object
 #' @param contextMenu logical enabling the right-click menu
 #' @param stretchH character describing column stretching. Options are 'all', 'right',
-#'  and 'none'. See \href{http://docs.handsontable.com/0.16.1/demo-stretching.html}{Column stretching} for details.
-#' @param customBorders json object. See
-#'  \href{http://handsontable.com/demo/custom_borders.html}{Custom borders} for details.
+#'  and 'none'
+#' @param customBorders json object
 #' @param highlightRow logical enabling row highlighting for the selected
 #'  cell
 #' @param highlightCol logical enabling column highlighting for the
@@ -230,10 +229,7 @@ hot_table = function(hot, contextMenu = TRUE, stretchH = "none",
 
 #' Handsontable widget
 #'
-#' Configure the options for the right-click context menu.  See
-#'  \href{http://docs.handsontable.com/0.16.1/demo-context-menu.html}{Context Menu} and
-#'  \href{http://swisnl.github.io/jQuery-contextMenu/docs.html}{jquery contextMenu}
-#'  for details.
+#' Configure the options for the right-click context menu
 #'
 #' @param hot rhandsontable object
 #' @param allowRowEdit logical enabling row editing
@@ -478,7 +474,8 @@ hot_col = function(hot, col, type = NULL, format = NULL, source = NULL,
 
 #' Handsontable widget
 #'
-#' Configure rows.  See
+#' Configure row settings that pertain to the entire table.
+#' Note that hot_rows is not to be confused with \code{\link{hot_row}}. See
 #' \href{http://handsontable.com}{Handsontable.js} for details.
 #'
 #' @param hot rhandsontable object
@@ -503,29 +500,31 @@ hot_rows = function(hot, rowHeights = NULL, fixedRowsTop = NULL) {
 
 #' Handsontable widget
 #'
-#' Configure a row.  See
+#' Configure properties of all cells in a given row(s).
+#' Note that hot_row is not to be confused with \code{\link{hot_rows}}.  See
 #' \href{http://handsontable.com}{Handsontable.js} for details.
 #'
 #' @param hot rhandsontable object
-#' @param row numeric row index
-#' @param readOnly logical making the row read-only
+#' @param row numeric vector of row indexes
+#' @param readOnly logical making the row(s) read-only
 #' @examples
 #' library(rhandsontable)
 #' MAT = matrix(rnorm(50), nrow = 10, dimnames = list(LETTERS[1:10],
 #'              letters[1:5]))
 #'
 #' rhandsontable(MAT, width = 300, height = 150) %>%
-#'   hot_row(1, readOnly = TRUE)
-#' @seealso \code{\link{hot_cols}}, \code{\link{hot_cell}}
+#'   hot_row(c(1,3:5), readOnly = TRUE)
+#' @seealso \code{\link{hot_cols}}, \code{\link{hot_cell}}, \code{\link{hot_rows}}
 #' @export
 hot_row = function(hot, row, readOnly = NULL) {
-  ct = hot$x$rDataDim[1]
-  for (i in seq_len(ct)) {
-    if (!is.null(readOnly)) {
-      hot =  hot %>% hot_cell(row, i, readOnly = readOnly)
-    }
-  }
-
+	if ( !is.null(readOnly) ) {
+		colDim = hot$x$rDataDim[2]
+		for ( i in row ) {
+			for ( j in seq_len(colDim) ) {
+				hot = hot %>% hot_cell(i, j, readOnly = readOnly)
+			}
+		}
+	}
   hot
 }
 
@@ -596,16 +595,26 @@ hot_validate_numeric = function(hot, cols, min = NULL, max = NULL,
                                 choices = NULL, exclude = NULL,
                                 allowInvalid = FALSE) {
   f = "function (value, callback) {
-         setTimeout(function(){
-           if (isNaN(parseFloat(value))) {
-             callback(false);
-           }
-           %exclude
-           %min
-           %max
-           %choices
-           return callback(true);
-         }, 500)
+          if (value === null || value === void 0) {
+            value = '';
+          }
+          if (this.allowEmpty && value === '') {
+            return callback(true);
+          } else if (value === '') {
+            return callback(false);
+          }
+          let isNumber = /^-?\\d*(\\.|,)?\\d*$/.test(value);
+          if (!isNumber) {
+            return callback(false);
+          }
+          if (isNaN(parseFloat(value))) {
+            return callback(false);
+          }
+          %exclude
+          %min
+          %max
+          %choices
+          return callback(true);
        }"
 
   if (!is.null(exclude))
@@ -690,9 +699,7 @@ hot_validate_character = function(hot, cols, choices,
 
 #' Handsontable widget
 #'
-#' Add heatmap to table.  See
-#' \href{http://docs.handsontable.com/0.16.1/demo-chromajs.html}{Heatmaps for values in a column}
-#' for details.
+#' Add heatmap to table.
 #'
 #' @param hot rhandsontable object
 #' @param cols numeric vector of columns to include in the heatmap. If missing
